@@ -409,9 +409,12 @@ pango_hb_shape (PangoFont           *font,
     for (i = 0; i < num_glyphs; i++)
       {
         /* 90 degrees rotation counter-clockwise. */
-	infos[i].geometry.width    =   hb_position->y_advance;
-	infos[i].geometry.x_offset =   hb_position->y_offset;
-	infos[i].geometry.y_offset = - hb_position->x_offset;
+	hb_position_t x_origin = 0, y_origin = 0;
+	hb_font_get_glyph_v_origin
+	  (hb_font, infos[i].glyph, &x_origin, &y_origin);
+	infos[i].geometry.width    = - hb_position->y_advance;
+	infos[i].geometry.x_offset = - hb_position->y_offset - y_origin;
+	infos[i].geometry.y_offset = - hb_position->x_offset - x_origin;
 	hb_position++;
       }
   else /* horizontal */
